
-- input controls demo

-- initialize controls
love.keyboard.setKeyRepeat(true)
input = require "input" -- the action(s) to take from user input
keys = {}               -- the raw input a user can give

-- initialize level
border = {x=5, y=5}
border.w, border.h = love.graphics.getDimensions()
border.w = border.w - 10
border.h = border.h - 40

-- initialize player data
player = {}
player.x, player.y = love.graphics.getDimensions()
player.x = math.floor(player.x/2)
player.y = math.floor(player.y/2)
player.speed = 10
player.rad = 10
player.qtrPi = math.pi / 4
player.draw = function()
    love.graphics.setColor(1, 1, 0)
    love.graphics.circle("fill", player.x, player.y, player.rad)
    love.graphics.setColor(0, 0, 0)
    love.graphics.line(player.x - 3, player.y - 3, player.x - 3, player.y)
    love.graphics.line(player.x + 3, player.y - 3, player.x + 3, player.y)
    love.graphics.arc("line", "open", player.x, player.y, 7, player.qtrPi, player.qtrPi * 3)
end

function love.load()

    -- define key bindings
    keys.up    = input.up
    keys.down  = input.down
    keys.left  = input.left
    keys.right = input.right
    keys.escape = love.event.quit
    
    -- can also WASD to move
    -- using scancodes to be compatible with international keyboards
    -- ideally, have this configurable in your game
    local scancodes = {}
    scancodes.w = love.keyboard.getScancodeFromKey("w")
    scancodes.a = love.keyboard.getScancodeFromKey("a")
    scancodes.s = love.keyboard.getScancodeFromKey("s")
    scancodes.d = love.keyboard.getScancodeFromKey("d")
    keys[love.keyboard.getKeyFromScancode(scancodes.w)] = input.up
    keys[love.keyboard.getKeyFromScancode(scancodes.a)] = input.left
    keys[love.keyboard.getKeyFromScancode(scancodes.s)] = input.down
    keys[love.keyboard.getKeyFromScancode(scancodes.d)] = input.right
end

function love.keypressed(key)
    if keys[key] then keys[key]() end
end

function love.touchmoved(_, _, _, dx, dy) -- we only care about swipe deltas for this demo
    -- there's probably a more efficient/elegant way to implement this, but this is my first go at touch input  :P
    local speedX, speedY = math.abs(dx), math.abs(dy)
    if math.max(speedX, speedY) > 10 then -- ignore small swipes
        if speedX > speedY then
            if dx < 0 then input.left() else input.right() end
        else
            if dy < 0 then input.up() else input.down() end
        end
    end
end

function love.draw()
    love.graphics.setColor(1, 1, 1)
    love.graphics.print("Arrow keys or WASD/equivalent to move\nESC to quit", border.x, border.y + border.h + 2)
    love.graphics.print("Also supports swipe to move", border.x + 400, border.y + border.h + 2)
    love.graphics.setColor(0, 0.6, 1)
    love.graphics.rectangle("fill", border.x, border.y, border.w, border.h)
    player.draw()
end
